# textdecorator-faiz

A small Python package to decorate terminal text.

## Install
pip install textdecorator-faiz

## Use
from textdecorator import box, success, error

box("Hello")
success("Done")
error("Failed")
